@@ -1,7 +1,7 @@
 /*
  * Standard routines for Mathomatic.
  *
- * Copyright (C) 1987-2011 George Gesslein II.
+ * Copyright (C) 1987-2012 George Gesslein II.
  
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -17,7 +17,7 @@ You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-The chief copyright holder can be contacted at gesslein@linux.com, or
+The chief copyright holder can be contacted at gesslein@mathomatic.org, or
 George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
  
  */
@@ -174,7 +174,7 @@ malloc_vscreen(void)
 			if (vscreen[i]) {
 				free(vscreen[i]);
 			}
-			vscreen[i] = malloc(current_columns);
+			vscreen[i] = malloc(current_columns + 1);
 			if (vscreen[i] == NULL) {
 				error(_("Out of memory (can't malloc(3))."));
 				current_columns = 0;
@@ -250,6 +250,34 @@ free_mem(void)
 }
 #endif
 
+#if	DEBUG
+/*
+ * Use this function to check for any erroneous global conditions.
+ */
+int
+check_gvars(void)
+{
+	if (!(domain_check == false &&
+	high_prec == false &&
+	partial_flag == true &&
+	symb_flag == false &&
+	sign_cmp_flag == false &&
+	approximate_roots == false &&
+	repeat_flag == false))
+		error_bug("Global vars got changed!");
+
+	if (!(zero_token.level == 1 &&
+	zero_token.kind == CONSTANT &&
+	zero_token.token.constant == 0.0 &&
+	one_token.level == 1 &&
+	one_token.kind == CONSTANT &&
+	one_token.token.constant == 1.0))
+		error_bug("Global constants got changed!");
+
+	return true;
+}
+#endif
+
 /*
  * Initialize some important global variables to their defaults.
  * This is called on startup and by process() to reset the global flags to the default state.
@@ -502,12 +530,14 @@ int	src, dest;	/* equation space numbers */
 }
 
 /*
- * Return true if equation space "i" is solved for a normal variable.
+ * Return true if equation space "i" is a valid equation solved for a normal variable.
  */
 int
 solved_equation(i)
 int	i;
 {
+	if (empty_equation_space(i))
+		return false;
 	if (n_rhs[i] <= 0)
 		return false;
 	if (n_lhs[i] != 1 || lhs[i][0].kind != VARIABLE || (lhs[i][0].token.variable & VAR_MASK) <= SIGN)
@@ -547,7 +577,7 @@ var_in_equation(i, v)
 int	i;	/* equation space number */
 long	v;	/* standard Mathomatic variable */
 {
-	if (n_lhs[i] <= 0)
+	if (empty_equation_space(i))
 		return false;
 	if (found_var(lhs[i], n_lhs[i], v))
 		return true;
@@ -558,6 +588,41 @@ long	v;	/* standard Mathomatic variable */
 	return false;
 }
 
+/*
+ * Return true if variable "v" exists in any equation space.
+ *
+ * Search forward starting at the next equation space if forward_direction is true,
+ * otherwise search backwards starting at the previous equation space.
+ * If found, return true with cur_equation set to the equation space the variable is found in.
+ */
+int
+search_all_for_var(v, forward_direction)
+long	v;
+int	forward_direction;
+{
+	int	i, n;
+
+	i = cur_equation;
+	for (n = 0; n < n_equations; n++) {
+		if (forward_direction) {
+			if (i >= (n_equations - 1))
+				i = 0;
+			else
+				i++;
+		} else {
+			if (i <= 0)
+				i = n_equations - 1;
+			else
+				i--;
+		}
+		if (var_in_equation(i, v)) {
+			cur_equation = i;
+			return true;
+		}
+	}
+	return false;
+}
+
 /*
  * Replace all occurrences of variable from_v with to_v in an equation space.
  */
@@ -568,6 +633,13 @@ long	from_v, to_v;	/* Mathomatic variables */
 {
 	int	i;
 
+	if (en < 0 || en >= n_equations) {
+#if	DEBUG
+		error_bug("Invalid equation number given to rename_var_in_es().");
+#else
+		return;
+#endif
+	}
 	if (n_lhs[en]) {
 		for (i = 0; i < n_lhs[en]; i += 2)
 			if (lhs[en][i].kind == VARIABLE
@@ -765,7 +837,7 @@ int	i;	/* equation space number */
 /*
  * Verify that a current equation or expression is loaded.
  *
- * Return true and display a message if current equation space is empty.
+ * Return true and display a message if the current equation space is empty or not defined.
  */
 int
 current_not_defined(void)
@@ -773,7 +845,12 @@ current_not_defined(void)
 	int	i;
 
 	i = cur_equation;
-	if (i < 0 || i >= n_equations || n_lhs[i] <= 0) {
+	if (i < 0 || i >= n_equations) {
+		error(_("Current equation number out of range; reset to 1."));
+		i = cur_equation = 0;
+		return true;
+	}
+	if (n_lhs[i] <= 0) {
 		error(_("No current equation or expression."));
 		return true;
 	}
@@ -898,16 +975,16 @@ int
 return_result(en)
 int	en;	/* equation space number the result is in */
 {
-	if (n_lhs[en] <= 0) {
+	if (empty_equation_space(en)) {
 		return false;
 	}
 #if	LIBRARY
 	make_fractions_and_group(en);
 	if (factor_int_flag) {
-		factor_int_sub(en);
+		factor_int_equation(en);
 	}
 	free_result_str();
-#if	ROBOT_COMMAND	/* Set this to 1 to have multi-line, fraction format output from most Mathomatic commands in library mode. */
+#if	1	/* Set this to 1 to allow display2d to decide library output mode. */
 	if (display2d) {
 		result_str = flist_equation_string(en);
 		if (result_str == NULL)
@@ -915,7 +992,7 @@ int	en;	/* equation space number the result is in */
 	} else {
 		result_str = list_equation(en, false);
 	}
-#else	/* Allow feeding command output to the next command's input. */
+#else	/* For feeding command output to the next command's input only. */
 	result_str = list_equation(en, false);
 #endif
 	result_en = en;
@@ -991,11 +1068,12 @@ int	*ip, *jp;
 				return true;
 			} else {
 use_current:
-				if (current_not_defined()) {
-					return false;
-				}
 				*jp = *ip = cur_equation;
-				return true;
+#if	1
+				return(!empty_equation_space(cur_equation));	/* don't display error message */
+#else
+				return(!current_not_defined());		/* display an error message if error */
+#endif
 			}
 		}
 		(cp)++;
@@ -1008,7 +1086,7 @@ use_current:
 			goto use_current;
 		}
 		if (*ip < 0 || *ip >= N_EQUATIONS || *jp < 0 || *jp >= N_EQUATIONS) {
-			error(_("Invalid equation number."));
+			error(_("Invalid equation number (out of range)."));
 			return false;
 		}
 		if (*jp < *ip) {
@@ -1082,6 +1160,20 @@ char	*cp;	/* character pointer */
 	return cp;
 }
 
+/*
+ * Skip over comma and space characters.
+ */
+char *
+skip_comma_space(cp)
+char	*cp;	/* character pointer */
+{
+	if (cp) {
+		while (*cp && (*cp == ',' || isspace(*cp)))
+			cp++;
+	}
+	return cp;
+}
+
 /*
  * Enhanced decimal strtol().
  * Skips trailing spaces.
@@ -1298,6 +1390,43 @@ int		n1;	/* expression length */
 	return true;
 }
 
+/*
+ * Test if expression contains an absolute value.
+ * Return true if it does.
+ */
+int
+exp_is_absolute(p1, n1)
+token_type	*p1;	/* expression pointer */
+int		n1;	/* expression length */
+{
+	int	i;
+	int	level;
+
+#if	1
+	for (i = n1 - 2; i > 2; i -= 2) {
+		if (p1[i].token.operatr != POWER)
+			continue;
+		level = p1[i].level;
+		if (p1[i+1].level == level && p1[i+1].kind == CONSTANT && fmod(p1[i+1].token.constant, 1.0) != 0.0) {
+			level++;
+			if (p1[i-2].token.operatr == POWER && p1[i-2].level == level && p1[i-1].level == level && p1[i-1].kind == CONSTANT) {
+				return true;
+			}
+		}
+	}
+#else
+	for (i = n1 - 2; i > 0; i -= 2) {
+		if (p1[i].token.operatr != POWER)
+			continue;
+		level = p1[i].level;
+		if (p1[i+1].level == level && p1[i+1].kind == CONSTANT && fmod(p1[i+1].token.constant, 1.0) != 0.0) {
+			return true;
+		}
+	}
+#endif
+	return false;
+}
+
 /*
  * Check for division by zero.
  *
