@@ -259,6 +259,7 @@ version_report(void)
 #endif
 
 	fprintf(gfp, "\nsizeof(int) = %u bytes, sizeof(long) = %u bytes.\n", (unsigned) sizeof(int), (unsigned) sizeof(long));
+	fprintf(gfp, "sizeof(double) = %u bytes, %d digits precision.\n", (unsigned) sizeof(double), DBL_DIG);
 #ifdef	__VERSION__
 	fprintf(gfp, _("C Compiler version: %s\n"), __VERSION__);
 #endif
@@ -276,7 +277,7 @@ version_report(void)
 	fprintf(gfp, _("The current security level is %d"), security_level);
 	switch (security_level) {
 	case 0:
-		fprintf(gfp, _(", no security.\n"));
+		fprintf(gfp, _(", no security, meaning users are unrestricted.\n"));
 		break;
 	case 3:
 		fprintf(gfp, _(", high security.\n"));
@@ -1113,10 +1114,9 @@ FILE	*ofp;	/* output file pointer */
 	}
 	fprintf(ofp, "factor_integers\n");
 
-	if (!right_associative_power) {
-		fprintf(ofp, "no ");
+	if (right_associative_power) {	/* option is hardly ever used */
+		fprintf(ofp, "right_associative_power\n");
 	}
-	fprintf(ofp, "right_associative_power\n");
 
 	fprintf(ofp, "plot_prefix = ");
 	fprintf_escaped(ofp, plot_prefix);
@@ -2211,16 +2211,16 @@ char	*cp;
 				approximate(lhs[i], &n_lhs[i]);
 				approximate(lhs[j], &n_lhs[j]);
 			}
+			if (compare_es(i, j)) {
+				fprintf(gfp, _("Expressions are identical.\n"));
+				return true;
+			}
 #if	!SILENT
 			if (debug_level >= 0) {
 				list_sub(i);
 				list_sub(j);
 			}
 #endif
-			if (compare_es(i, j)) {
-				fprintf(gfp, _("Expressions are identical.\n"));
-				return true;
-			}
 			uf_simp(lhs[i], &n_lhs[i]);
 			uf_simp(lhs[j], &n_lhs[j]);
 			if (approx) {
@@ -2264,15 +2264,15 @@ char	*cp;
 			approximate(rhs[i], &n_rhs[i]);
 			approximate(rhs[j], &n_rhs[j]);
 		}
+		if (compare_rhs(i, j, &diff_sign)) {
+			goto times_neg1;
+		}
 #if	!SILENT
 		if (debug_level >= 0) {
 			list_sub(i);
 			list_sub(j);
 		}
 #endif
-		if (compare_rhs(i, j, &diff_sign)) {
-			goto times_neg1;
-		}
 		uf_simp(rhs[i], &n_rhs[i]);
 		uf_simp(rhs[j], &n_rhs[j]);
 		if (approx) {
@@ -3908,7 +3908,8 @@ char	*cp;
 	}
 #if	!SILENT
 	if (rv) {
-		printf(_("Read operation on file \"%s\" aborted due to error.\n"), buf);
+		printf(_("Reading of file \"%s\" aborted due to failure return status\n"), buf);
+		printf(_("of a command or expression parsing, or some other error listed above.\n"));
 	} else {
 		if (!quiet_mode && debug_level >= 0) {
 			printf(_("Successfully finished reading file \"%s\".\n"), buf);
