@@ -1,7 +1,7 @@
 /*
  * Floating point complex number routines specifically for Mathomatic.
  *
- * Copyright (C) 1987-2011 George Gesslein II.
+ * Copyright (C) 1987-2012 George Gesslein II.
  
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -17,7 +17,7 @@ You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-The chief copyright holder can be contacted at gesslein@linux.com, or
+The chief copyright holder can be contacted at gesslein@mathomatic.org, or
 George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
  
  */
@@ -258,9 +258,11 @@ double		*dp;	/* pointer to returned double */
 	double	d1, d2;
 	int	prev_approx_flag;
 
+#if	DEBUG
 	if (n < 1 || (n & 1) != 1) {
 		error_bug("Call to get_constant() has invalid expression length.");
 	}
+#endif
 	if (n == 1) {
 		switch (p1[0].kind) {
 		case CONSTANT:
@@ -279,8 +281,12 @@ double		*dp;	/* pointer to returned double */
 		if (!get_constant(p1, 1, &d1))
 			return false;
 		for (i = 1; i < n; i = j) {
-			if (p1[i].kind != OPERATOR || p1[i].level > level)
+			if (p1[i].kind != OPERATOR || p1[i].level > level) {
+#if	DEBUG
+				error_bug("Possible error in get_constant().");
+#endif
 				return false;
+			}
 			level = p1[i].level;
 			for (j = i + 2; j < n && p1[j].level > level; j += 2)
 				;
@@ -295,6 +301,7 @@ double		*dp;	/* pointer to returned double */
 				domain_check = false;
 			} else {
 				approximate_roots = prev_approx_flag;
+				domain_check = false;
 				return false;
 			}
 		}
@@ -308,8 +315,10 @@ double		*dp;	/* pointer to returned double */
  * Get the value of a constant complex number expression.
  * Doesn't always work unless expression is approximated first
  * with something like the approximate command.
+ * Functionality was greatly improved recently, making success more likely
+ * without approximating.
  *
- * If successful return true with complex number in *cp.
+ * If successful, return true with complex number in *cp.
  */
 int
 parse_complex(p1, n, cp)
@@ -317,20 +326,49 @@ token_type	*p1;	/* expression pointer */
 int		n;	/* length of expression */
 complexs	*cp;	/* pointer to returned complex number */
 {
-	int		j;
-	int		imag_cnt = 0, plus_cnt = 0, times_cnt = 0;
-	complexs	c;
+	int		j, k;
+	int		imag_cnt = 0, times_cnt = 0;
+	complexs	c, tmp;
 	int		level, level2;
 
+	if (!exp_is_numeric(p1, n)) {
+		return false;
+	}
 	if (get_constant(p1, n, &c.re)) {
 		c.im = 0.0;
 		*cp = c;
 		return true;
 	}
+	if (found_var(p1, n, IMAGINARY) != 1)
+		return false;
 	level = min_level(p1, n);
 	c.re = 0.0;
 	c.im = 1.0;
-	for (j = n - 1; j >= 0; j--) {
+	j = n - 1;
+	do {
+		for (k = j - 1; k > 0 && p1[k].level > level; k -= 2)
+			;
+		if (k > 0) {
+#if	DEBUG
+			if (p1[k].level != level || p1[k].kind != OPERATOR) {
+				error_bug("Error in parse_complex().");
+			}
+#endif
+			switch (p1[k].token.operatr) {
+			case MINUS:
+			case PLUS:
+				if (get_constant(&p1[k+1], j - k, &tmp.re)) {
+					if (p1[k].token.operatr == MINUS)
+						c.re -= tmp.re;
+					else
+						c.re += tmp.re;
+					j = k - 1;
+				}
+			}
+		} else
+			break;
+	} while (j < k);
+	for (; j >= 0; j--) {
 		switch (p1[j].kind) {
 		case CONSTANT:
 			break;
@@ -339,62 +377,79 @@ complexs	*cp;	/* pointer to returned complex number */
 				break;
 			if (p1[j].token.variable != IMAGINARY)
 				return false;
-			imag_cnt++;
+			++imag_cnt;
 			break;
 		case OPERATOR:
 			level2 = p1[j].level;
 			switch (p1[j].token.operatr) {
 			case TIMES:
-				if (++times_cnt > 1)
-					return false;
-				if (p1[j-1].level != level2 || p1[j+1].level != level2)
-					return false;
-				if (p1[j-1].kind == VARIABLE && p1[j-1].token.variable == IMAGINARY) {
-					if (!get_constant(&p1[j+1], 1, &c.im))
-						return false;
-					continue;
-				}
-				if (p1[j+1].kind == VARIABLE && p1[j+1].token.variable == IMAGINARY) {
-					if (!get_constant(&p1[j-1], 1, &c.im))
-						return false;
-					continue;
-				}
-				return false;
 			case DIVIDE:
 				if (++times_cnt > 1)
 					return false;
-				if (p1[j-1].level != level2 || p1[j+1].level != level2)
+				if (level2 > (level + 1) || p1[j+1].level != level2)
 					return false;
-				if (p1[j-1].kind == VARIABLE && p1[j-1].token.variable == IMAGINARY) {
-					if (!get_constant(&p1[j+1], 1, &c.im))
+				for (k = j; k > 0 && p1[k].level == level2; k -= 2) {
+					if (p1[k-1].level != level2)
 						return false;
-					c.im = 1.0 / c.im;
-					continue;
+					if (!(p1[k+1].kind == VARIABLE && p1[k+1].token.variable == IMAGINARY)) {
+						if (get_constant(&p1[k+1], 1, &tmp.im)) {
+							if (p1[k].token.operatr == DIVIDE)
+								c.im /= tmp.im;
+							else
+								c.im *= tmp.im;
+						} else
+							return false;
+					} else if (p1[k].token.operatr == DIVIDE) {
+						c.im = -c.im;
+					}
+					if (p1[k-1].kind == VARIABLE && p1[k-1].token.variable == IMAGINARY) {
+						if (++imag_cnt > 1)
+							return false;
+						k -= 2;
+						if (k > 0 && p1[k].level == level2) {
+							if (p1[k-1].level != level2)
+								return false;
+							if (p1[k-1].kind == VARIABLE && p1[k-1].token.variable == IMAGINARY)
+								return false;
+							if (p1[k].token.operatr == DIVIDE)
+								c.im = -c.im;
+						} else
+							break;
+					}		
 				}
-				return false;
+				if (!(p1[k+1].kind == VARIABLE && p1[k+1].token.variable == IMAGINARY)) {
+					if (get_constant(&p1[k+1], 1, &tmp.im)) {
+						c.im *= tmp.im;
+					} else
+						return false;
+				}
+				j = k + 1;
+				continue;
 			case MINUS:
 				if (imag_cnt) {
 					c.im = -c.im;
 				}
 			case PLUS:
-				if (++plus_cnt > 1 || level != level2)
+				if (level != level2)
 					return false;
-				if (get_constant(p1, j, &c.re)) {
+				if (get_constant(p1, j, &tmp.re)) {
+					c.re += tmp.re;
 					goto done;
 				}
-				if (get_constant(&p1[j+1], n - (j + 1), &c.re)) {
-					if (p1[j].token.operatr == MINUS)
-						c.re = -c.re;
-					continue;
-				}
+				return false;
 			}
 		default:
 			return false;
 		}
 	}
 done:
-	if (imag_cnt != 1)
+	if (imag_cnt != 1) {
+#if	DEBUG
+		error_bug("Imaginary count wrong in parse_complex().");
+#else
 		return false;
+#endif
+	}
 	*cp = c;
 	return true;
 }
