@@ -1,7 +1,7 @@
 /*
  * Mathomatic symbolic differentiation routines and related commands.
  *
- * Copyright (C) 1987-2011 George Gesslein II.
+ * Copyright (C) 1987-2012 George Gesslein II.
  
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -17,7 +17,7 @@ You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-The chief copyright holder can be contacted at gesslein@linux.com, or
+The chief copyright holder can be contacted at gesslein@mathomatic.org, or
 George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
  
  */
@@ -726,7 +726,7 @@ loop_again:
 			}
 		}
 		symb_flag = symblify;
-		simpa_repeat_side(rhs[our], &our_nrhs, true, true);
+		simpa_repeat_side(rhs[our], &our_nrhs, true, false /* was true */);
 		symb_flag = false;
 		if (our_nrhs != 1 || rhs[our][0].kind != CONSTANT || rhs[our][0].token.constant != 0.0) {
 			i1 = n1;
