@@ -24,6 +24,8 @@ George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
 
 #include "includes.h"
 
+#define	ALWAYS_FACTOR_POWER	1
+
 static int fplus_recurse(token_type *equation, int *np, int loc, int level, long v, double d, int whole_flag, int div_only);
 static int fplus_sub(token_type *equation, int *np, int loc, int i1, int n1, int i2, int n2, int level, long v, double d, int whole_flag, int div_only);
 static int big_fplus(token_type *equation, int level, int diff_sign, int sop1, int op1, int op2, int i1, int i2, int b1, int b2, int ai, int aj, int i, int j, int e1, int e2);
@@ -976,6 +978,9 @@ int		*np, loc, i1, n1, i2, n2, level;
 	int		len;
 	int		diff_sign;
 	int		all_divide;
+#if	!ALWAYS_FACTOR_POWER
+	int		abs1_flag = false, abs2_flag = false;
+#endif
 
 	e1 = i1 + n1;
 	e2 = i2 + n2;
@@ -989,12 +994,22 @@ int		*np, loc, i1, n1, i2, n2, level;
 		if (i >= e1)
 			return false;
 		if (equation[i].level == level && equation[i].token.operatr == POWER) {
-#if	1
+#if	!ALWAYS_FACTOR_POWER
 /* avoid absolute values: */
-			if (i > (i1 + 2) && equation[i+1].level == level && equation[i-1].level == (level + 1)
-			    && equation[i+1].kind == CONSTANT && equation[i-1].kind == CONSTANT
+			if (i > (i1 + 2)
+			    && ((equation[i+1].level == level && (i + 2) == e1)
+			    || (equation[i+1].level == (level + 1)
+			    && (i + 4) == e1
+			    && equation[i+2].level == (level + 1)
+			    && equation[i+2].token.operatr == DIVIDE
+			    && equation[i+3].level == (level + 1)
+			    && equation[i+3].kind == CONSTANT))
+			    && equation[i-1].level == (level + 1)
+			    && equation[i+1].kind == CONSTANT
+			    && equation[i-1].kind == CONSTANT
 			    && equation[i-2].level == (level + 1) && equation[i-2].token.operatr == POWER) {
-				return false;
+				abs1_flag = true;
+/*				return false;	*/
 			}
 #endif
 			break;
@@ -1004,17 +1019,31 @@ int		*np, loc, i1, n1, i2, n2, level;
 		if (j >= e2)
 			return false;
 		if (equation[j].level == level && equation[j].token.operatr == POWER) {
-#if	1
+#if	!ALWAYS_FACTOR_POWER
 /* avoid absolute values: */
-			if (j > (i2 + 2) && equation[j+1].level == level && equation[j-1].level == (level + 1)
-			    && equation[j+1].kind == CONSTANT && equation[j-1].kind == CONSTANT
+			if (j > (i2 + 2)
+			    && ((equation[j+1].level == level && (j + 2) == e2)
+			    || (equation[j+1].level == (level + 1)
+			    && (j + 4) == e2
+			    && equation[j+2].level == (level + 1)
+			    && equation[j+2].token.operatr == DIVIDE
+			    && equation[j+3].level == (level + 1)
+			    && equation[j+3].kind == CONSTANT))
+			    && equation[j-1].level == (level + 1)
+			    && equation[j+1].kind == CONSTANT
+			    && equation[j-1].kind == CONSTANT
 			    && equation[j-2].level == (level + 1) && equation[j-2].token.operatr == POWER) {
-				return false;
+				abs2_flag = true;
+/*				return false;	*/
 			}
 #endif
 			break;
 		}
 	}
+#if	!ALWAYS_FACTOR_POWER
+	if (abs1_flag && abs2_flag)
+		return false;
+#endif
 	start2 = j;
 #if	1
 	if (se_compare(&equation[i+1], e1 - (i + 1), &one_token, 1, &diff_sign)) {
