@@ -6,7 +6,7 @@
  * double-to-fraction convert function is recommended.
  * It is heavily tested through extensive use in this computer algebra system.
  *
- * Copyright (C) 1987-2011 George Gesslein II.
+ * Copyright (C) 1987-2012 George Gesslein II.
  
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -22,7 +22,7 @@ You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-The chief copyright holder can be contacted at gesslein@linux.com, or
+The chief copyright holder can be contacted at gesslein@mathomatic.org, or
 George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
  
  */
@@ -186,6 +186,9 @@ double	*denominatorp;	/* returned denominator */
 		}
 		if (fmod(numerator, 1.0) != 0.0 || fmod(denominator, 1.0) != 0.0) {
 			/* Shouldn't happen if everything works. */
+#if	DEBUG
+			error_bug("Fraction should have been fully reduced by gcd(), but was not.");
+#endif
 			return false;
 		}
 /* numerator and denominator are guaranteed integral */
