@@ -5,7 +5,7 @@
  * C initializes global variables and arrays to zero by default.
  * This is required for proper operation.
  *
- * Copyright (C) 1987-2011 George Gesslein II.
+ * Copyright (C) 1987-2012 George Gesslein II.
  
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,7 @@ You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-The chief copyright holder can be contacted at gesslein@linux.com, or
+The chief copyright holder can be contacted at gesslein@mathomatic.org, or
 George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
  
  */
@@ -56,7 +56,11 @@ token_type	zero_token,			/* the universal constant 0.0 as an expression */
 int		precision = 14;				/* the display precision for doubles (number of digits) */
 int		case_sensitive_flag = true;		/* "set case_sensitive" flag */
 int		factor_int_flag;			/* factor integers when displaying expressions */
-int		display2d = true;			/* "set display2d" flag */
+#if	LIBRARY && !ROBOT_COMMAND
+int		display2d = false;			/* "set no display2d" to allow feeding the output to the input */
+#else
+int		display2d = true;			/* "set display2d" flag for 2D display */
+#endif
 int		fractions_display = 1;			/* "set fraction" mode */
 int		preserve_surds = true;			/* set option to preserve roots like (2^.5) */
 int		rationalize_denominators = true;	/* try to rationalize denominators if true */
@@ -111,7 +115,7 @@ char		rc_file[MAX_CMD_LEN];		/* pathname for the set options startup file */
 char		*dir_path;			/* directory path to the executable */
 #endif
 #if	READLINE
-char		*last_history_string;
+char		*last_history_string;		/* To prevent repeated, identical entries.  Must not point to temporary string. */
 char		*history_filename;
 char		history_filename_storage[MAX_CMD_LEN];
 #endif
@@ -148,6 +152,7 @@ int		security_level;		/* current enforced security level for session, -1 for m4
 #endif
 int		repeat_flag;		/* true if the command is to repeat its function or simplification, set by repeat command */
 int		show_usage;		/* show command usage info if a command fails and this flag is true */
+int		point_flag;		/* point to location of parse error if true */
 
 /* library variables go here */
 char		*result_str;		/* returned result text string when using as library */
