@@ -148,8 +148,9 @@ char	*example_strings[] = {
 char	*geometry_strings[] = {
 	"; Triangle area:\n",
 	"triangle_area = base*height/2\n",
-	"; See Heron's formula for the area of any triangle\n",
-	"; given all three side lengths.\n",
+	"; Here is Heron's formula for the area of any triangle\n",
+	"; given all three side lengths (a, b, and c):\n",
+	"triangle_area = (((a + b + c)*(a - b + c)*(a + b - c)*(b - a + c))^(1/2))/4\n",
 	"\n",
 	"; Rectangle of length \"l\" and width \"w\":\n",
 	"rectangle_area = l*w\n",
@@ -350,12 +351,18 @@ int
 process(cp)
 char	*cp;
 {
+	int	rv;
+
 	if (cp && cp[0] == ':') {
 		input_column++;
 		process_rv(cp + 1);
 		return true;
 	} else {
-		return process_rv(cp);
+		rv = process_rv(cp);
+		if (!rv) {
+			debug_string(1, "Error return.");
+		}
+		return rv;
 	}
 }
 
@@ -921,11 +928,12 @@ next_argument:
 
 			P("If a colon (:) starts the line, preceding any of the above input to the main");
 			P("prompt, it will always return with successful status, preventing any current");
-			P("read command operations from aborting.");
+			P("read command operation from aborting due to an error return status.");
 
 			goto next_space;
 		}
-		if (strncasecmp(cp, "copyrights", cp1 - cp) == 0 || strncasecmp(cp, "licenses", cp1 - cp) == 0) {
+		if (strncasecmp(cp, "copyrights", cp1 - cp) == 0
+		    || strncasecmp(cp, "licenses", cp1 - cp) == 0 || strncasecmp(cp, "licences", cp1 - cp) == 0) {
 			underline_title(P("Copyright and License for Mathomatic"));
 
 			fprintf(gfp, "%s", license_string);
