@@ -15,16 +15,23 @@ main(int argc, char **argv)
 	char		*ocp;		/* output character pointer */
 	int		rv;		/* return value */
 	char		buf[1000];	/* buffer */
+	char		*version;	/* version number of the library */
 
 	printf("Mathomatic library test/example program.\n");
-	printf("Press EOF character (Control-D) to exit.\n");
 	/* Initialize all global variables and arrays so that Mathomatic will work properly. */
 	if (!matho_init()) {	/* call this library function exactly once in your program */
 		fprintf(stderr, "Not enough memory.\n");
 		exit(1);
 	}
 	/* Mathomatic is ready for use. */
+	if (matho_process("version", &version)) {
+		printf("Mathomatic library version %s\n", version);
+	} else {
+		printf("Error getting library version number.\n");
+	}
+
 	/* This is a standard input/output loop for testing. */
+	printf("Press the EOF character (Control-D) to exit.\n");
 	for (;;) {
 		printf("%d-> ", cur_equation + 1);
 		fflush(stdout);
