@@ -40,4 +40,6 @@ char	*license_string =
 "    George Gesslein II\n"
 "    P.O. Box 224\n"
 "    Lansing, New York  14882-0224\n"
-"    USA\n";
+"    USA\n\n"
+
+"Others who have contributed code to Mathomatic are listed in file \"AUTHORS\".\n";
