@@ -795,20 +795,20 @@ int			int_flag;	/* integer arithmetic flag */
  * Return string, or NULL if error.
  */
 char *
-string_code_equation(n, language, int_flag)
-int			n;		/* equation space number */
+string_code_equation(en, language, int_flag)
+int			en;		/* equation space number */
 enum language_list	language;
 int			int_flag;	/* integer arithmetic flag */
 {
 	int	len;
 	char	*cp;
 
-	if (empty_equation_space(n))
+	if (empty_equation_space(en))
 		return NULL;
-	len = list_code(lhs[n], &n_lhs[n], false, NULL, language, int_flag);
-	if (n_rhs[n]) {
+	len = list_code(lhs[en], &n_lhs[en], false, NULL, language, int_flag);
+	if (n_rhs[en]) {
 		len += strlen(EQUATE_STRING);
-		len += list_code(rhs[n], &n_rhs[n], false, NULL, language, int_flag);
+		len += list_code(rhs[en], &n_rhs[en], false, NULL, language, int_flag);
 	}
 	len += 2;	/* for possible semicolon and terminating null character */
 	cp = (char *) malloc(len);
@@ -816,10 +816,10 @@ int			int_flag;	/* integer arithmetic flag */
 		error(_("Out of memory (can't malloc(3))."));
 		return NULL;
 	}
-	list_code(lhs[n], &n_lhs[n], false, cp, language, int_flag);
-	if (n_rhs[n]) {
+	list_code(lhs[en], &n_lhs[en], false, cp, language, int_flag);
+	if (n_rhs[en]) {
 		strcat(cp, EQUATE_STRING);
-		list_code(rhs[n], &n_rhs[n], false, &cp[strlen(cp)], language, int_flag);
+		list_code(rhs[en], &n_rhs[en], false, &cp[strlen(cp)], language, int_flag);
 	}
 	switch (language) {
 	case C:
