@@ -88,7 +88,10 @@ FILE	*fp;
 		fprintf(fp, "m4 ");
 #endif
 	fprintf(fp, "Mathomatic version %s\n", VERSION);
-	fprintf(fp, "Copyright (C) 1987-2012 George Gesslein II.\n");
+	if (html_flag)
+		fprintf(fp, "Copyright &copy; 1987-2012 George Gesslein II.\n");
+	else
+		fprintf(fp, "Copyright (C) 1987-2012 George Gesslein II.\n");
 	fprintf(fp, _("%d equation spaces available in memory,\n%ld kilobytes per equation space.\n"),
 	    N_EQUATIONS, (long) n_tokens * sizeof(token_type) * 2L / 1000L);
 }
