@@ -1,7 +1,7 @@
 /*
  * Expression parsing routines for Mathomatic.
  *
- * Copyright (C) 1987-2011 George Gesslein II.
+ * Copyright (C) 1987-2012 George Gesslein II.
  
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -17,15 +17,13 @@ You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-The chief copyright holder can be contacted at gesslein@linux.com, or
+The chief copyright holder can be contacted at gesslein@mathomatic.org, or
 George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
  
  */
 
 #include "includes.h"
 
-int	point_flag;		/* point to location of parse error if true */
-
 /*
  * Convert all alphabetic characters in a string to lower case.
  */
@@ -302,7 +300,7 @@ int		allow_space;	/* if false, any space characters terminate parsing */
 			continue;
 		case '\033':
 			if (cp[1] == '[' || cp[1] == 'O') {
-				error(_("Cursor or function key string encountered, unable to correct."));
+				error(_("Cursor or function key string encountered, unable to interpret."));
 				return(NULL);
 			}
 			continue;
@@ -875,6 +873,8 @@ double	*dp;
 
 /*
  * Substitute E and PI variables with their respective constants.
+ *
+ * Return true if anything was substituted (therefore approximated).
  */
 int
 subst_constants(equation, np)
