@@ -1023,22 +1023,28 @@ int		*np, loc, level;
 				}
 				break;
 			}
+#if	1
 			/* Remove integer*n multiples in x for x%n by doing */
 			/* polynomial division x/n and replacing with remainder%n. */
 			/* Globals tlhs[] and trhs[] are wiped out by the polynomial division here. */
 			if (poly_div(&equation[j], len2, &equation[i+1], len1, NULL)) {
 				uf_pplus(tlhs, &n_tlhs);	/* so integer%(integer^integer) isn't simplified to 0 */
 				if (is_integer_expr(tlhs, n_tlhs)) {
-					if ((*np + (n_trhs - len2)) > n_tokens)
-						error_huge();
-					for (k = 0; k < n_trhs; k++)
-						trhs[k].level += level;
-					blt(&equation[j+n_trhs], &equation[j+len2], (*np - (j + len2)) * sizeof(token_type));
-					*np += n_trhs - len2;
-					blt(&equation[j], trhs, n_trhs * sizeof(token_type));
-					return true;
+					if (n_trhs < len2 || REMAINDER_IS_ZERO()) {	/* if it will make it smaller */
+						if ((*np + (n_trhs - len2)) > n_tokens)
+							error_huge();
+						for (k = 0; k < n_trhs; k++)
+							trhs[k].level += level;
+						blt(&equation[j+n_trhs], &equation[j+len2], (*np - (j + len2)) * sizeof(token_type));
+						*np += n_trhs - len2;
+						blt(&equation[j], trhs, n_trhs * sizeof(token_type));
+						debug_string(2, "Polynomial division successful in modulus simplification.  The result is:");
+						side_debug(2, equation, *np);
+						return true;
+					}
 				}
 			}
+#endif
 		}
 	}
 	return modified;
@@ -1552,9 +1558,12 @@ long		*vp;
 		count = find_greatest_power(trhs, n_trhs, vp, &d, &t1, &len_t1, &divide_flag);
 		if (d < divisor_power) {
 			/* Success!  Polynomial division ends here. */
+			debug_string(3, "Successful polynomial division!");
 			blt(tlhs, quotient, n_quotient * sizeof(token_type));
 			n_tlhs = n_quotient;
+			debug_string(3, "Quotient:");
 			side_debug(3, tlhs, n_tlhs);
+			debug_string(3, "Remainder:");
 			side_debug(3, trhs, n_trhs);
 			if (REMAINDER_IS_ZERO())
 				return 2;
