@@ -2,7 +2,7 @@
  * Generate batches of consecutive prime numbers using a modified Sieve of Eratosthenes
  * algorithm that doesn't use much memory by using a windowing sieve buffer.
  *
- * Copyright (C) 1987-2011 George Gesslein II.
+ * Copyright (C) 1987-2012 George Gesslein II.
  
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -18,7 +18,7 @@ You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-The chief copyright holder can be contacted at gesslein@linux.com, or
+The chief copyright holder can be contacted at gesslein@mathomatic.org, or
 George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
  
  */
@@ -37,6 +37,8 @@ George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
  * 1/16/11 - Allow to use doubles instead of long doubles with USE_DOUBLES define, for systems that don't fully support long doubles.
  * 5/10/11 - Added -u (unbuffered output) option, for real-time output.
  * 11/13/11 - Use EXIT_SUCCESS and EXIT_FAILURE macros.
+ * 11/30/11 - Added -m option.
+ * 12/31/11 - Added a compile-time warning when the number of digits of precision of long doubles is less than 18.
  */
 
 #include <stdio.h>
@@ -53,7 +55,7 @@ George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
 #include <getopt.h>
 #endif
 
-#define	VERSION	"1.2"	/* The current version number of this primes program. */
+#define	VERSION		"1.3"	/* The current version number of this primes program. */
 
 #define	true	1
 #define	false	0
@@ -70,6 +72,8 @@ George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
 
 #ifndef	LDBL_DIG
 #define	USE_DOUBLES	1
+#elif LDBL_DIG < 18
+#warning "long double number of digits precision is less than 18."
 #endif
 
 #if	USE_DOUBLES
@@ -83,8 +87,8 @@ typedef long double double_type;
 #ifndef	BUFFER_SIZE
 #define BUFFER_SIZE	2000000
 #endif
-#if	BUFFER_SIZE >= (INT_MAX / 2) || BUFFER_SIZE <= 0
-#warning BUFFER_SIZE out of range, using INT_MAX / 2.
+#if	BUFFER_SIZE >= (INT_MAX / 2) || BUFFER_SIZE < 100
+#warning BUFFER_SIZE out of range, using default.
 #undef BUFFER_SIZE
 #define BUFFER_SIZE	min((INT_MAX / 2), 2000000)
 #endif
@@ -132,7 +136,10 @@ main(int argc, char *argv[])
 
 	int		i;
 	char		buf[1000];
+	char		*cp = NULL;
+	double		new_size = 0;
 
+	buffer_size = BUFFER_SIZE;
 /* set the highest number this program will work with: */
 #if	USE_DOUBLES
 	max_integer = pow(10.0, (double) (DBL_DIG));
@@ -156,7 +163,7 @@ do_again:
 	number = 0;
 	count_requested = false;
 /* process command line options: */
-	while ((i = getopt(argc, argv, "c:thup:")) >= 0) {
+	while ((i = getopt(argc, argv, "c:thup:m:")) >= 0) {
 		switch (i) {
 		case 'c':
 			count_requested = true;
@@ -176,6 +183,16 @@ do_again:
 				usage2(EXIT_FAILURE);
 			}
 			break;
+		case 'm':
+			if (optarg)
+				new_size = strtod(optarg, &cp) * BUFFER_SIZE;
+			if (optarg == NULL || cp == NULL || *cp || new_size < 100 || new_size >= (INT_MAX / 2)) {
+				fprintf(stderr, "%s: Invalid memory size multiplier specified.\n", prog_name);
+				exit(EXIT_FAILURE);
+			}
+			buffer_size = (int) new_size;
+			fprintf(stderr, "%s: Window size = %d bytes.\n", prog_name, buffer_size);
+			break;
 		case 'u':
 			setbuf(stdout, NULL);	/* make output unbuffered */
 			setbuf(stderr, NULL);
@@ -288,10 +305,6 @@ get2:
 	}
 	if (prime == NULL) {
 /* allocate the prime[] buffer: */
-		buffer_size = BUFFER_SIZE;
-#if	0
-		fprintf(stderr, "buffer_size = %d bytes.\n", buffer_size);
-#endif
 		prime = (char *) malloc(buffer_size);
 	}
 	if (prime == NULL) {
@@ -539,6 +552,7 @@ usage2(int ev)
 	printf("Options:\n");
 	printf("  -c count         Count lines of primes, stop when count reached.\n");
 	printf("  -h               Display this help and exit.\n");
+        printf("  -m number        Specify a memory size multiplier.\n");
 	printf("  -p base          Output only palindromic primes.\n");
 	printf("  -t               Output only twin primes.\n");
 	printf("  -u               Set all output to be unbuffered.\n");
