@@ -17,7 +17,7 @@ You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-The chief copyright holder can be contacted at gesslein@linux.com, or
+The chief copyright holder can be contacted at gesslein@mathomatic.org, or
 George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
  
  */
@@ -30,8 +30,7 @@ George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
  * integers is 2 (default "multi"), all combinations with 2 squares are displayed,
  * otherwise only the first solution found is displayed.
  *
- * If nothing is specified on the command line, the program starts at 0 and
- * counts up.
+ * If nothing is specified on the command line, the program gets its numbers from standard input.
  *
  * This file is mostly useful for testing the long integer square root function lsqrt() in file "lsqrt.c".
  */
@@ -157,22 +156,25 @@ main(int argc, char *argv[])
 {
 	int	i;
 	long	d1 = 0;
-	char	*cp;
+	char	*cp, buf[1000];
 
 	if (argc > 1) {
 		for (i = 1; i < argc; i++) {
 			errno = 0;
 			d1 = strtol(argv[i], &cp, 10);
 			if (errno) {
-				perror(NULL);
+				perror(argv[i]);
 				exit(EXIT_FAILURE);
 			}
-			if (d1 <= 0) {
+			if (d1 < 0) {
 				fprintf(stderr, "Invalid command-line argument: \"%s\", positive integer required.\n", argv[i]);
 				exit(EXIT_FAILURE);
 			}
 			if (*cp == '+') {
-				goto count_up;
+				for (;; d1 += 1) {
+					findsq(d1);
+				}
+				exit(EXIT_SUCCESS);
 			}
 			if (argv[i][0] == '\0' || *cp) {
 				fprintf(stderr, "Invalid number: \"%s\".\n", argv[i]);
@@ -181,8 +183,17 @@ main(int argc, char *argv[])
 			findsq(d1);
 		}
 	} else {
-count_up:
-		for (;; d1 += 1) {
+		while (fgets(buf, sizeof(buf), stdin)) {
+			errno = 0;
+			d1 = strtol(buf, &cp, 10);
+			if (errno) {
+				perror(NULL);
+				continue;
+			}
+			if (d1 <= 0) {
+				fprintf(stderr, "Positive integer required.\n");
+				continue;
+			}
 			findsq(d1);
 		}
 	}
