@@ -189,7 +189,7 @@ int list_string(token_type *p1, int n, char *string, int export_flag);
 int list_string_sub(token_type *p1, int n, int outflag, char *string, int export_flag);
 int int_expr(token_type *p1, int n);
 int list_code_equation(int en, enum language_list language, int int_flag);
-char *string_code_equation(int n, enum language_list language, int int_flag);
+char *string_code_equation(int en, enum language_list language, int int_flag);
 int list_code(token_type *equation, int *np, int outflag, char *string, enum language_list language, int int_flag);
 char *flist_equation_string(int n);
 int flist_equation(int n);
