@@ -1,7 +1,7 @@
 /*
  * Mathomatic simplifying routines.
  *
- * Copyright (C) 1987-2011 George Gesslein II.
+ * Copyright (C) 1987-2012 George Gesslein II.
  
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -17,7 +17,7 @@ You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-The chief copyright holder can be contacted at gesslein@linux.com, or
+The chief copyright holder can be contacted at gesslein@mathomatic.org, or
 George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
  
  */
@@ -183,7 +183,7 @@ int		*np;		/* pointer to length of equation side */
 #if	DEBUG && !SILENT
 		char	*cp, buf[100];
 
-		my_strlcpy(prompt_str, _("Enter debug level or empty line to abort: "), sizeof(prompt_str));
+		my_strlcpy(prompt_str, _("Enter debug level, or an empty line to abort the current operation: "), sizeof(prompt_str));
 		if ((cp = get_string(buf, sizeof(buf))) == NULL || *cp == '\0') {
 			longjmp(jmp_save, 13);
 		} else {
@@ -249,7 +249,7 @@ void
 simp_equation(n)
 int	n;	/* equation space number to simplify */
 {
-	if (n_lhs[n] <= 0)
+	if (empty_equation_space(n))
 		return;
 	simp_loop(lhs[n], &n_lhs[n]);
 	if (n_rhs[n] > 0) {
@@ -277,7 +277,7 @@ void
 mid_simp_equation(n)
 int	n;	/* equation space number to simplify */
 {
-	if (n_lhs[n] <= 0)
+	if (empty_equation_space(n))
 		return;
 	mid_simp_side(lhs[n], &n_lhs[n]);
 	if (n_rhs[n] > 0) {
@@ -322,7 +322,7 @@ simpv_equation(n, v)
 int	n;	/* equation space number to simplify */
 long	v;	/* Mathomatic variable to factor or 0 */
 {
-	if (n_lhs[n] <= 0)
+	if (empty_equation_space(n))
 		return;
 	simpv_side(lhs[n], &n_lhs[n], v);
 	if (n_rhs[n] > 0) {
@@ -390,64 +390,95 @@ int		*np;
 
 /*
  * Approximate an equation side for the approximate command.
+ *
+ * Return true if something was approximated.
  */
-void
+int
 approximate(equation, np)
 token_type	*equation;
 int		*np;
 {
-	subst_constants(equation, np);
+	int	rv;
+
+	rv = subst_constants(equation, np);
 	approximate_roots = true;
 	simp_loop(equation, np);
-	factor_imaginary(equation, np);
+	if (factor_imaginary(equation, np)) {
+		rv = true;
+	}
 	approximate_roots = false;
+	return rv;
 }
 
 /*
- * Try to eliminate imaginary numbers (i#) from an equation side by converting
+ * Try to eliminate imaginary units (i#) from an equation side by converting
  * expressions like (i#*(b^.5)) to ((-1*b)^.5).
+ *
+ * Return true if any imaginary units where substituted.
  */
-void
+int
 simp_i(equation, np)
 token_type	*equation;
 int		*np;
 {
 	int	i;
 	int	level;
+	int	rv = false;
 
 	simp_loop(equation, np);
-	for (i = 0; i < *np; i += 2) {
-		if (equation[i].kind == VARIABLE && equation[i].token.variable == IMAGINARY) {
-			if (*np + 2 > n_tokens) {
-				error_huge();
+	for (i = 0; i < *np; i++) {
+		switch (equation[i].kind) {
+		case VARIABLE:
+			if (equation[i].token.variable == IMAGINARY) {
+				if (*np + 2 > n_tokens) {
+					error_huge();
+				}
+				level = equation[i].level + 1;
+				blt(&equation[i+2], &equation[i], (*np - i) * sizeof(token_type));
+				*np += 2;
+				equation[i].level = level;
+				equation[i].kind = CONSTANT;
+				equation[i].token.constant = -1.0;
+				i++;
+				equation[i].level = level;
+				equation[i].kind = OPERATOR;
+				equation[i].token.operatr = POWER;
+				i++;
+				equation[i].level = level;
+				equation[i].kind = CONSTANT;
+				equation[i].token.constant = 0.5;
+				rv = true;
 			}
-			level = equation[i].level + 1;
-			blt(&equation[i+2], &equation[i], (*np - i) * sizeof(token_type));
-			*np += 2;
-			equation[i].level = level;
-			equation[i].kind = CONSTANT;
-			equation[i].token.constant = -1.0;
-			i++;
-			equation[i].level = level;
-			equation[i].kind = OPERATOR;
-			equation[i].token.operatr = POWER;
-			i++;
-			equation[i].level = level;
-			equation[i].kind = CONSTANT;
-			equation[i].token.constant = 0.5;
+			break;
+		case OPERATOR:
+#if	0
+			if (equation[i].token.operatr != POWER)
+				continue;
+			level = equation[i].level;
+/* Skip imaginary units on the right side of any power operator. */
+			for (; i < *np && equation[i].level >= level; i += 2)
+				;
+			i--;
+#endif
+			break;
+		case CONSTANT:
+			break;
 		}
 	}
 	do {
 		do {
 			do {
 				do {
-					organize(equation, np);
-					combine_constants(equation, np, false);
+					do {
+						organize(equation, np);
+					} while (combine_constants(equation, np, false));
 				} while (elim_k(equation, np));
 			} while (simp_pp(equation, np));
+/* The following factor_power() messes up absolute values and complex numbers sometimes: */
 		} while (factor_power(equation, np));
 	} while (factor_times(equation, np));
 	simp_loop(equation, np);
+	return rv;
 }
 
 /*
@@ -617,7 +648,7 @@ int		*np;		/* pointer to length of equation side */
 				simp_ssub(equation, np, 0L, 0.0, false, true, 5);
 			} while (poly_gcd_simp(equation, np));
 		} while (uf_power(equation, np));
-	} while (super_factor(equation, np, 2));
+	} while (super_factor(equation, np, 3));
 	side_debug(2, equation, *np);
 
 	make_simple_fractions(equation, np);
@@ -657,7 +688,16 @@ int		frac_flag;	/* "simplify fraction" option, simplify to the ratio of two poly
 	debug_string(2, "Simplify input:");
 	side_debug(2, equation, *np);
 	simp_loop(equation, np);
+#if	1
+	do {
+		simp_ssub(equation, np, 0L, 1.0, false, true, 5);
+	} while (uf_power(equation, np));
+	while (factor_power(equation, np)) {
+		simp_loop(equation, np);
+	}
+#else
 	simpb_side(equation, np, false, true, 5);
+#endif
 	if (rationalize_denominators) {
 		rationalize(equation, np);
 	}
@@ -823,7 +863,7 @@ int	n;		/* equation space number to simplify */
 int	quick_flag;	/* "simplify quick" option, simpler fractions with no (x+1)^2 expansion */
 int	frac_flag;	/* "simplify fraction" option, simplify to the ratio of two polynomials */
 {
-	if (n_lhs[n] <= 0)
+	if (empty_equation_space(n))
 		return;
 	simpa_repeat_side(lhs[n], &n_lhs[n], quick_flag, frac_flag);
 	if (n_rhs[n] > 0) {
@@ -1513,6 +1553,8 @@ beginning:
 					*np -= 2;
 					loc -= 2;
 				}
+			} else {
+				domain_check = false;
 			}
 		}
 	}
@@ -2027,6 +2069,10 @@ no_op2:
 						first = false;
 					}
 					break;
+/*				case POWER:
+Someday fix so that (x-y)^6 compares identical to (y-x)^6.
+Also (x-y)^5 should compare identical with different sign to (y-x)^5.
+*/
 				default:
 					if (j)
 						continue;
@@ -2060,8 +2106,7 @@ no_op2:
 
 /*
  * Take out meaningless "sign" variables and negative constants.
- * Simplify imaginary numbers raised to the power of some constants,
- * including simple division (1/i# -> -1*i#).
+ * Simplify imaginary numbers raised to the power of some constants.
  *
  * Return true if equation side was modified.
  */
@@ -2078,33 +2123,12 @@ int		*np;
 	double		numerator, denominator;
 
 	for (i = 1; i < *np; i += 2) {
-		level = equation[i].level;
-#if	1	/* This code makes complex number calculations give different (maybe wrong) results. */
-		/* It converts x/i to x*-1*i.  Might be better to do this only when symb_flag is true. */
-		if (equation[i].token.operatr == DIVIDE) {
-			if (equation[i+1].level == level
-			    && equation[i+1].kind == VARIABLE
-			    && equation[i+1].token.variable == IMAGINARY) {
-				if (*np + 2 > n_tokens) {
-					error_huge();
-				}
-				blt(&equation[i+2], &equation[i], (*np - i) * sizeof(token_type));
-				*np += 2;
-				equation[i].level = level;
-				equation[i].kind = OPERATOR;
-				equation[i].token.operatr = TIMES;
-				i++;
-				equation[i].level = level;
-				equation[i].kind = CONSTANT;
-				equation[i].token.constant = -1.0;
-				i++;
-				equation[i].level = level;
-				equation[i].kind = OPERATOR;
-				equation[i].token.operatr = TIMES;
-				modified = true;
-			}
+#if	DEBUG
+		if (equation[i].kind != OPERATOR) {
+			error_bug("Error in elim_sign().");
 		}
 #endif
+		level = equation[i].level;
 		if (equation[i].token.operatr == POWER
 		    && equation[i+1].level == level
 		    && equation[i+1].kind == CONSTANT) {
@@ -2184,6 +2208,8 @@ int		*np;
  * the conjugate of the complex number in the denominator.
  * This often complicates expressions, so use with care.
  *
+ * Includes simple division (1/i# -> -1*i#) conversions now.
+ *
  * Return true if equation side was modified.
  */
 int
@@ -2198,10 +2224,41 @@ int		*np;
 	int		op;
 	int		iloc, biloc, eiloc;
 	int		eloc;
+	int		modified = false;
 
 	for (i = 1; i < *np; i += 2) {
+#if	DEBUG
+		if (equation[i].kind != OPERATOR) {
+			error_bug("Error in div_imaginary().");
+		}
+#endif
 		if (equation[i].token.operatr == DIVIDE) {
 			level = equation[i].level;
+#if	1	/* This necessary code makes complex number calculations give different (maybe wrong) results. */
+		/* It converts x/i to x*-1*i.  Might be better to do this only when symb_flag is true. */
+			if (equation[i+1].level == level
+			    && equation[i+1].kind == VARIABLE
+			    && equation[i+1].token.variable == IMAGINARY) {
+				if (*np + 2 > n_tokens) {
+					error_huge();
+				}
+				blt(&equation[i+2], &equation[i], (*np - i) * sizeof(token_type));
+				*np += 2;
+				equation[i].level = level;
+				equation[i].kind = OPERATOR;
+				equation[i].token.operatr = TIMES;
+				i++;
+				equation[i].level = level;
+				equation[i].kind = CONSTANT;
+				equation[i].token.constant = -1.0;
+				i++;
+				equation[i].level = level;
+				equation[i].kind = OPERATOR;
+				equation[i].token.operatr = TIMES;
+				modified = true;
+				continue;
+			}
+#endif
 			op = 0;
 			iloc = biloc = eiloc = -1;
 			k = i;
@@ -2294,11 +2351,12 @@ int		*np;
 			blt(&equation[i+1+n], &equation[i], (*np - i) * sizeof(token_type));
 			*np += n + 1;
 			blt(&equation[i+1], scratch, n * sizeof(token_type));
-			equation[i+1+n].token.operatr = TIMES;
-			return true;
+			i += n + 1;
+			equation[i].token.operatr = TIMES;
+			modified = true;
 		}
 	}
-	return false;
+	return modified;
 }
 
 /*
@@ -2533,9 +2591,17 @@ do_again:
 							if (equation[k1].token.operatr == POWER
 							    && equation[k1].level == equation[k1+1].level
 							    && equation[k1+1].kind == CONSTANT
-							    && fmod(equation[k1+1].token.constant, 1.0) == 0.5
-							    && k != k1) {
-								if (!(equation[k1].level == (div_level + 2) && count == 1)) {
+							    && fmod(equation[k1+1].token.constant, 1.0) == 0.5) {
+								/* make sure we will actually be eliminating ^.5 from the denominator: */
+								if (k != k1 && !(equation[k1].level == (div_level + 2) && count == 1)) {
+									i += 2;
+									goto be_thorough;
+								}
+								/* avoid rationalizing absolute values: */
+								if (equation[k1-1].level == (equation[k1].level + 1)
+								    && equation[k1-2].level == equation[k1-1].level
+								    && equation[k1-1].kind == CONSTANT
+								    && equation[k1-2].token.operatr == POWER) {
 									i += 2;
 									goto be_thorough;
 								}
