@@ -1117,7 +1117,7 @@ int		*side2np;	/* pointer to the length of "side2p" */
 		error_bug("g_of_f() called with invalid operandp.");
 	}
 	if (*side1np == prev_n1 && *side2np == prev_n2) {
-		if (++repeat_count >= 4 /* was 3 */) {
+		if (++repeat_count >= 4) {
 			debug_string(1, _("Infinite loop aborted in solve routine."));
 			return false;
 		}
@@ -1261,7 +1261,7 @@ int		*side2np;	/* pointer to the length of "side2p" */
 		p2++;
 		p2->level = 2;
 		p2->kind = VARIABLE;
-		snprintf(var_name_buf, sizeof(var_name_buf), "%s%.0d", V_INTEGER_PREFIX, last_int_var);
+		snprintf(var_name_buf, sizeof(var_name_buf), "%s_any%.0d", V_INTEGER_PREFIX, last_int_var);
 		if (parse_var(&p2->token.variable, var_name_buf) == NULL)
 			return false;
 		last_int_var++;
